/*  monkey-sound
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: monkey-media-mixer.h,v 1.13 2002/08/03 01:17:52 jbaayen Exp $
 */

#ifndef __MONKEY_MEDIA_MIXER_H
#define __MONKEY_MEDIA_MIXER_H

#include <glib-object.h>

#include "monkey-media-stream.h"
#include "monkey-media-audio-stream.h"

G_BEGIN_DECLS

typedef enum
{
          MONKEY_MEDIA_MIXER_STATE_STOPPED,
	  MONKEY_MEDIA_MIXER_STATE_PLAYING,
	  MONKEY_MEDIA_MIXER_STATE_PAUSED
} MonkeyMediaMixerState;

#define MONKEY_MEDIA_TYPE_MIXER_STATE (monkey_media_mixer_state_get_type ())

GType monkey_media_mixer_state_get_type (void);

typedef enum
{
	MONKEY_MEDIA_MIXER_OPTIONS_CROSSFADE        = 1 << 0,
	MONKEY_MEDIA_MIXER_OPTIONS_VOLUME_NORMALIZE = 1 << 1
} MonkeyMediaMixerOptions;

typedef enum
{
	MONKEY_MEDIA_MIXER_EQUALIZER_BAND_PREAMP,
	MONKEY_MEDIA_MIXER_EQUALIZER_BAND_60,
	MONKEY_MEDIA_MIXER_EQUALIZER_BAND_170,
	MONKEY_MEDIA_MIXER_EQUALIZER_BAND_310,
	MONKEY_MEDIA_MIXER_EQUALIZER_BAND_600,
	MONKEY_MEDIA_MIXER_EQUALIZER_BAND_1000,
	MONKEY_MEDIA_MIXER_EQUALIZER_BAND_3000,
	MONKEY_MEDIA_MIXER_EQUALIZER_BAND_6000,
	MONKEY_MEDIA_MIXER_EQUALIZER_BAND_12000,
	MONKEY_MEDIA_MIXER_EQUALIZER_BAND_14000,
	MONKEY_MEDIA_MIXER_EQUALIZER_BAND_16000
} MonkeyMediaMixerEqualizerBand;

#define MONKEY_MEDIA_TYPE_MIXER_EQUALIZER_BAND (monkey_media_mixer_equalizer_band_get_type ())

GType monkey_media_mixer_equalizer_band_get_type (void);

typedef enum
{
        MONKEY_MEDIA_MIXER_ERROR_ELEMENT_MISSING
} MonkeyMediaMixerError;

#define MONKEY_MEDIA_MIXER_ERROR (monkey_media_mixer_error_quark ())

GQuark monkey_media_mixer_error_quark (void);

#define MONKEY_MEDIA_TYPE_MIXER         (monkey_media_mixer_get_type ())
#define MONKEY_MEDIA_MIXER(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), MONKEY_MEDIA_TYPE_MIXER, MonkeyMediaMixer))
#define MONKEY_MEDIA_MIXER_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), MONKEY_MEDIA_TYPE_MIXER, MonkeyMediaMixerClass))
#define MONKEY_MEDIA_IS_MIXER(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), MONKEY_MEDIA_TYPE_MIXER))
#define MONKEY_MEDIA_IS_MIXER_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), MONKEY_MEDIA_TYPE_MIXER))
#define MONKEY_MEDIA_MIXER_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), MONKEY_MEDIA_TYPE_MIXER, MonkeyMediaMixerClass))

typedef struct MonkeyMediaMixerPrivate MonkeyMediaMixerPrivate;

typedef struct
{
	GObject parent;

	MonkeyMediaMixerPrivate *priv;
} MonkeyMediaMixer;

typedef struct
{
	GObjectClass parent_class;

	void (*end_of_queue) (MonkeyMediaMixer *mixer);
} MonkeyMediaMixerClass;

GType		        monkey_media_mixer_get_type                 (void);

MonkeyMediaMixer       *monkey_media_mixer_new                      (GError **error);

/* options: not implemented yet */
void		        monkey_media_mixer_set_options	            (MonkeyMediaMixer *mixer,
						                     MonkeyMediaMixerOptions options);

MonkeyMediaMixerOptions monkey_media_mixer_get_options              (MonkeyMediaMixer *mixer);

void		        monkey_media_mixer_set_state	            (MonkeyMediaMixer *mixer,
                                                                     MonkeyMediaMixerState state);

MonkeyMediaMixerState   monkey_media_mixer_get_state	            (MonkeyMediaMixer *mixer);

void		        monkey_media_mixer_append_audio_stream      (MonkeyMediaMixer *mixer,
					                             MonkeyMediaAudioStream *stream);

void		        monkey_media_mixer_remove_audio_stream      (MonkeyMediaMixer *mixer,
						                     MonkeyMediaAudioStream *stream);

const GList *		monkey_media_mixer_list_audio_streams       (MonkeyMediaMixer *mixer);

void		        monkey_media_mixer_set_playing_audio_stream (MonkeyMediaMixer *mixer,
						                     MonkeyMediaAudioStream *stream);

MonkeyMediaAudioStream *monkey_media_mixer_get_playing_audio_stream (MonkeyMediaMixer *mixer);

void                    monkey_media_mixer_set_volume               (MonkeyMediaMixer *mixer, 
					                             float volume);

float                   monkey_media_mixer_get_volume               (MonkeyMediaMixer *mixer);

void                    monkey_media_mixer_set_mute                 (MonkeyMediaMixer *mixer, 
					                             gboolean mute);

gboolean                monkey_media_mixer_get_mute                 (MonkeyMediaMixer *mixer);

/* equalizer: not implemented yet */
void                    monkey_media_mixer_set_equalizer_band       (MonkeyMediaMixer *mixer,
							             MonkeyMediaMixerEqualizerBand band,
							             float value);

float                   monkey_media_mixer_get_equalizer_band       (MonkeyMediaMixer *mixer,
							             MonkeyMediaMixerEqualizerBand band);

G_END_DECLS

#endif /* __MONKEY_MEDIA_MIXER_H */
