/*  monkey-sound
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *                     Marco Pesenti Gritti <marco@it.gnome.org>
 *                     Bastien Nocera <hadess@hadess.net>
 *                     Seth Nickell <snickell@stanford.edu>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: monkey-media-stream.h,v 1.13 2002/10/24 21:37:26 jbaayen Exp $
 */

#ifndef __MONKEY_MEDIA_STREAM_H
#define __MONKEY_MEDIA_STREAM_H

#include <glib-object.h>

#include "monkey-media-stream-info.h"

G_BEGIN_DECLS

typedef enum
{
	MONKEY_MEDIA_STREAM_ERROR_OPEN_FAILED,
	MONKEY_MEDIA_STREAM_ERROR_ELEMENT_MISSING
} MonkeyMediaStreamError;

#define MONKEY_MEDIA_STREAM_ERROR (monkey_media_stream_error_quark ())

GQuark monkey_media_stream_error_quark (void);

#define MONKEY_MEDIA_TYPE_STREAM         (monkey_media_stream_get_type ())
#define MONKEY_MEDIA_STREAM(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), MONKEY_MEDIA_TYPE_STREAM, MonkeyMediaStream))
#define MONKEY_MEDIA_STREAM_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), MONKEY_MEDIA_TYPE_STREAM, MonkeyMediaStreamClass))
#define MONKEY_MEDIA_IS_STREAM(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), MONKEY_MEDIA_TYPE_STREAM))
#define MONKEY_MEDIA_IS_STREAM_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), MONKEY_MEDIA_TYPE_STREAM))
#define MONKEY_MEDIA_STREAM_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), MONKEY_MEDIA_TYPE_STREAM, MonkeyMediaStreamClass))

typedef struct MonkeyMediaStreamPrivate MonkeyMediaStreamPrivate;

typedef struct
{
	GObject parent;

	MonkeyMediaStreamPrivate *priv;
} MonkeyMediaStream;

typedef struct
{
        GObjectClass parent_class;

	/* signals */
	void (*end_of_stream)           (MonkeyMediaStream *ms);

	void (*info_available)          (MonkeyMediaStream *ms, MonkeyMediaStreamInfoField field, GValue *value);

	/* implementation */
	void     (*impl_construct_pipeline) (MonkeyMediaStream *ms);
	void     (*impl_end_of_stream)      (MonkeyMediaStream *ms);
	gboolean (*impl_seek)               (MonkeyMediaStream *ms,
					     long seconds);
} MonkeyMediaStreamClass;

GType    monkey_media_stream_get_type         (void);

gboolean monkey_media_stream_set_elapsed_time (MonkeyMediaStream *ms,
					       long seconds);

long     monkey_media_stream_get_elapsed_time (MonkeyMediaStream *ms);

G_END_DECLS

#endif /* __MONKEY_MEDIA_STREAM_H */
