/*
 *  Copyright (C) 2002 Jorn Baayen <jorn@nl.linux.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: monkey-media-visualization.h,v 1.1 2002/10/25 00:05:02 jbaayen Exp $
 */

#ifndef __MONKEY_MEDIA_VISUALIZATION_H
#define __MONKEY_MEDIA_VISUALIZATION_H

#include <gtk/gtksocket.h>

#include "monkey-media-mixer.h"

G_BEGIN_DECLS

typedef enum
{
	MONKEY_MEDIA_VISUALIZATION_ERROR_ELEMENT_MISSING
} MonkeyMediaVisualizationError;

#define MONKEY_MEDIA_VISUALIZATION_ERROR (monkey_media_visualization_error_quark ())

GQuark monkey_media_visualization_error_quark (void);

#define MONKEY_MEDIA_TYPE_VISUALIZATION         (monkey_media_visualization_get_type ())
#define MONKEY_MEDIA_VISUALIZATION(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), MONKEY_MEDIA_TYPE_VISUALIZATION, MonkeyMediaVisualization))
#define MONKEY_MEDIA_VISUALIZATION_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), MONKEY_MEDIA_TYPE_VISUALIZATION, MonkeyMediaVisualizationClass))
#define MONKEY_MEDIA_IS_VISUALIZATION(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), MONKEY_MEDIA_TYPE_VISUALIZATION))
#define MONKEY_MEDIA_IS_VISUALIZATION_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), MONKEY_MEDIA_TYPE_VISUALIZATION))
#define MONKEY_MEDIA_VISUALIZATION_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), MONKEY_MEDIA_TYPE_VISUALIZATION, MonkeyMediaVisualizationClass))

typedef struct MonkeyMediaVisualizationPrivate MonkeyMediaVisualizationPrivate;

typedef struct
{
	GtkSocket parent;

	MonkeyMediaVisualizationPrivate *priv;
} MonkeyMediaVisualization;

typedef struct
{
	GtkSocketClass parent_class;
} MonkeyMediaVisualizationClass;

GType                     monkey_media_visualization_get_type    (void);

MonkeyMediaVisualization *monkey_media_visualization_new         (MonkeyMediaMixer *mixer,
					                          GError **error);

gboolean                  monkey_media_visualization_set_element (MonkeyMediaVisualization *vis,
					                          const char *vis_element_name,
								  GError **error);

void                      monkey_media_visualization_set_enabled (MonkeyMediaVisualization *vis,
								  gboolean enabled);

gboolean                  monkey_media_visualization_get_enabled (MonkeyMediaVisualization *vis);

typedef struct
{
	char *gstreamer_element_name;
	char *description;
	char *author;
} MonkeyMediaVisualizationPlugin;

GList *monkey_media_visualization_get_plugin_list  (void);

void   monkey_media_visualization_plugin_list_free (GList *list);

G_END_DECLS

#endif /* __MONKEY_MEDIA_VISUALIZATION_H */
